LMCache Controller Dashboard

### Controller Overview

##### System Status

Loading...

##### Quick Stats

Loading...

##### Recent Activities

Loading...

### Instance Management

Instance ID | IP Address | Status | Worker Count | Key Count | Last Heartbeat | Actions
--- | --- | --- | --- | --- | --- | ---

### Worker Management

Instance ID | Worker ID | IP | Port | Status | Key Count | Last Heartbeat | Actions
--- | --- | --- | --- | --- | --- | --- | ---

### Performance Metrics

    Please connect to controller first

### Thread Information

    Please connect to controller first

### Environment Variables

    Please connect to controller first

##### Add New Instance

Instance ID
IP Address